#
# spec file for package ghc-servant-server
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name servant-server
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.19
Release:        bp154.1.18
Summary:        A family of combinators for defining webservices APIs and serving them
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-constraints-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-http-api-data-devel
BuildRequires:  ghc-http-media-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-servant-devel
BuildRequires:  ghc-sop-core-devel
BuildRequires:  ghc-string-conversions-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-wai-app-static-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-warp-devel
BuildRequires:  ghc-word8-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-wai-devel
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-should-not-typecheck-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-wai-extra-devel
%endif

%description
A family of combinators for defining webservices APIs and serving them

You can learn about the basics in the
<http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.

<https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs
Here> is a runnable example, with comments, that defines a dummy API and
implements a webserver that serves this API, using this package.

<https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md
CHANGELOG>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cabal-tweak-dep-ver base-compat '< 0.12' '< 1'

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/greet

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Wed Feb  2 2022 Peter Simons <psimons@suse.com>
- Update servant-server to version 0.19.
  Package versions follow the [Package Versioning Policy](https://pvp.haskell.org/): in A.B.C, bumps to either A or B represent major versions.
  0.19
  - ---
  [#]## Significant changes
  - Drop support for GHC < 8.6.
  - Support GHC 9.0 (GHC 9.2 should work as well, but isn't fully tested yet).
  - Support Aeson 2 ([#1475](https://github.com/haskell-servant/servant/pull/1475)),
    which fixes a [DOS vulnerability](https://github.com/haskell/aeson/issues/864)
    related to hash collisions.
  - Add `NamedRoutes` combinator, making support for records first-class in Servant
    ([#1388](https://github.com/haskell-servant/servant/pull/1388)).
  - Add custom type errors for partially applied combinators
    ([#1289](https://github.com/haskell-servant/servant/pull/1289),
    [#1486](https://github.com/haskell-servant/servant/pull/1486)).
* Tue Sep  7 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax dep constraints on base-compat-*
* Thu Jun 24 2021 psimons@suse.com
- Update servant-server to version 0.18.3.
  0.18.3
  - -----
  [#]## Significant changes
  - Add response header support to UVerb (#1420)
  [#]## Other changes
  - Support GHC-9.0.1.
  - Bump `bytestring`, `hspec` and `base64-bytestring` dependencies.
* Sat May 15 2021 psimons@suse.com
- Update servant-server to version 0.18.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jan 19 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax dep on http-api-data
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec  9 2020 psimons@suse.com
- Add servant-server at version 0.18.2.
